import requests
from copy import deepcopy
from config import LLM_SEARCH_HOST

url = LLM_SEARCH_HOST + "/chat/kb_chat"

common_params = {
    "query": "",
    "mode": "local_kb",
    "kb_name": "policy",
    "top_k": 3,
    "score_threshold": 0.5,
    "history": [],
    "stream": False,
    "model": "qwen1.5-chat",
    "temperature": 0.7,
    "max_tokens": 32768,
    "prompt_name": "",
    "return_direct": False
}


def kb_chat(query="南京市和杭州市在产业用地政策方面有哪些差异"):
    with open("resource/prompt/rag/rag_context_qa.md",encoding="utf-8") as f:
        prompt_template = f.read()
    params = deepcopy(common_params)
    params['query'] = query
    params['prompt_name'] = prompt_template

    return requests.post(url, json=params, stream=True)


def chat_regenerate(
        query="问题：南京市和杭州市在产业用地政策方面有哪些差异，历史回答：### 总结\\n\\n**工业及科技研发用地分类清晰**：南京市对工业及科技研发用地有明确的分类，包括工业用地（M1、M2、M3）和仓储用地（W1、W2、W3、Wa），科技研发用地则为科研设计用地（C65）和生产研发用地（Mx），统一登记为科教用地。\\n**土地利用强度强化**：南京市鼓励提高工业及科技研发用地的利用强度，可能包括优化工业项目布局，使用高标准厂房，提高容积率。\\n**土地供应灵活**：南京市支持通过长期租赁、先租后让等方式供应工业用地，弹性确定土地出让年限，对创新土地供应方式的区（园区）给予奖励。\\n**财政与基金支持**：南京市政府通过设立产业发展基金，鼓励科技产业发展，支持投贷联动，为科技企业提供全生命周期融资。\\n**集约用地政策**：南京市鼓励开发区实施土地租赁和先租后让，对工业项目优先利用存量土地，对工业用地加层扩建不再增收土地出让金。\\n**入园政策**：南京鼓励私营个体企业进入规划的工业园区投资创业，要求办理相关审批手续，确保用地合法。\\n**用地规划管理**：杭州市江干区、西湖区、余杭区对土地利用总体规划有清晰的控制指标，包括耕地保有量、建设用地规模等，强调土地用途管制和节约集约用地。\\n**产业项目支持**：杭州市对引进的外商投资先进制造业项目、防范和处置非法集资、社会信用体系建设等方面表现突出的地区给予用地计划优先、资金奖励等激励。\\n**省级开发区建设**：杭州的萧山区、余杭区、江干区及西湖区的多个街道和乡镇有详细的土地利用总体规划，强调保护耕地、优化建设用地结构。\\n\\n### 比较\\n\\n**南京市**着重于规范工业及科技研发用地管理，包括用地分类、提高土地利用强度，鼓励土地供应创新，以及对私营企业进入工业园区的引导。\\n\\n**杭州市**则在土地利用总体规划上更为细致，不仅有对土地用途、总量的控制，还强调土地用途管制和节约集约用地，同时对产业项目引进、风险防范和信用体系建设方面有激励政策。\\n\\n**对比**，两者都强调了土地保护和合理利用，南京市更侧重科技研发用地的管理，杭州市则在整体规划和产业项目支持上更为全面。两者都通过土地政策支持产业结构升级和科技创新。"):
    with open("resource/prompt/rag/rag_regenerate_qa.md",encoding="utf-8") as f:
        prompt_template = f.read()
    params = deepcopy(common_params)
    params['query'] = query
    params['prompt_name'] = prompt_template

    return requests.post(url, json=params, stream=True)


def chat_continue_ask(
        query="问题：南京市和杭州市在产业用地政策方面有哪些差异，历史回答：### 总结\\n\\n**工业及科技研发用地分类清晰**：南京市对工业及科技研发用地有明确的分类，包括工业用地（M1、M2、M3）和仓储用地（W1、W2、W3、Wa），科技研发用地则为科研设计用地（C65）和生产研发用地（Mx），统一登记为科教用地。\\n**土地利用强度强化**：南京市鼓励提高工业及科技研发用地的利用强度，可能包括优化工业项目布局，使用高标准厂房，提高容积率。\\n**土地供应灵活**：南京市支持通过长期租赁、先租后让等方式供应工业用地，弹性确定土地出让年限，对创新土地供应方式的区（园区）给予奖励。\\n**财政与基金支持**：南京市政府通过设立产业发展基金，鼓励科技产业发展，支持投贷联动，为科技企业提供全生命周期融资。\\n**集约用地政策**：南京市鼓励开发区实施土地租赁和先租后让，对工业项目优先利用存量土地，对工业用地加层扩建不再增收土地出让金。\\n**入园政策**：南京鼓励私营个体企业进入规划的工业园区投资创业，要求办理相关审批手续，确保用地合法。\\n**用地规划管理**：杭州市江干区、西湖区、余杭区对土地利用总体规划有清晰的控制指标，包括耕地保有量、建设用地规模等，强调土地用途管制和节约集约用地。\\n**产业项目支持**：杭州市对引进的外商投资先进制造业项目、防范和处置非法集资、社会信用体系建设等方面表现突出的地区给予用地计划优先、资金奖励等激励。\\n**省级开发区建设**：杭州的萧山区、余杭区、江干区及西湖区的多个街道和乡镇有详细的土地利用总体规划，强调保护耕地、优化建设用地结构。\\n\\n### 比较\\n\\n**南京市**着重于规范工业及科技研发用地管理，包括用地分类、提高土地利用强度，鼓励土地供应创新，以及对私营企业进入工业园区的引导。\\n\\n**杭州市**则在土地利用总体规划上更为细致，不仅有对土地用途、总量的控制，还强调土地用途管制和节约集约用地，同时对产业项目引进、风险防范和信用体系建设方面有激励政策。\\n\\n**对比**，两者都强调了土地保护和合理利用，南京市更侧重科技研发用地的管理，杭州市则在整体规划和产业项目支持上更为全面。两者都通过土地政策支持产业结构升级和科技创新。"):
    with open("resource/prompt/rag/rag_continue_ask_qa.md",encoding="utf-8") as f:
        prompt_template = f.read()
    params = deepcopy(common_params)
    params['query'] = query
    params['prompt_name'] = prompt_template

    return requests.post(url, json=params, stream=True)
